==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/enums/WebApplicationFirewallTransform.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * Transforms applied before matching.
 */
public enum class WebApplicationFirewallTransform(
    public val javaValue: com.pulumi.azurenative.network.enums.WebApplicationFirewallTransform,
) : ConvertibleToJava<com.pulumi.azurenative.network.enums.WebApplicationFirewallTransform> {
    Uppercase(com.pulumi.azurenative.network.enums.WebApplicationFirewallTransform.Uppercase),
    Lowercase(com.pulumi.azurenative.network.enums.WebApplicationFirewallTransform.Lowercase),
    Trim(com.pulumi.azurenative.network.enums.WebApplicationFirewallTransform.Trim),
    UrlDecode(com.pulumi.azurenative.network.enums.WebApplicationFirewallTransform.UrlDecode),
    UrlEncode(com.pulumi.azurenative.network.enums.WebApplicationFirewallTransform.UrlEncode),
    RemoveNulls(com.pulumi.azurenative.network.enums.WebApplicationFirewallTransform.RemoveNulls),
    HtmlEntityDecode(com.pulumi.azurenative.network.enums.WebApplicationFirewallTransform.HtmlEntityDecode),
    ;

    override fun toJava(): com.pulumi.azurenative.network.enums.WebApplicationFirewallTransform =
        javaValue

    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.network.enums.WebApplicationFirewallTransform):
            WebApplicationFirewallTransform =
            WebApplicationFirewallTransform.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/network/kotlin/enums/WebApplicationFirewallTransform.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * Transforms applied before matching.
 */
public enum class WebApplicationFirewallTransform(
    public val javaValue: com.pulumi.azurenative.network.enums.WebApplicationFirewallTransform,
) : ConvertibleToJava<com.pulumi.azurenative.network.enums.WebApplicationFirewallTransform> {
    Uppercase(com.pulumi.azurenative.network.enums.WebApplicationFirewallTransform.Uppercase),
    Lowercase(com.pulumi.azurenative.network.enums.WebApplicationFirewallTransform.Lowercase),
    Trim(com.pulumi.azurenative.network.enums.WebApplicationFirewallTransform.Trim),
    UrlDecode(com.pulumi.azurenative.network.enums.WebApplicationFirewallTransform.UrlDecode),
    UrlEncode(com.pulumi.azurenative.network.enums.WebApplicationFirewallTransform.UrlEncode),
    RemoveNulls(com.pulumi.azurenative.network.enums.WebApplicationFirewallTransform.RemoveNulls),
    HtmlEntityDecode(com.pulumi.azurenative.network.enums.WebApplicationFirewallTransform.HtmlEntityDecode),
    ;

    override fun toJava(): com.pulumi.azurenative.network.enums.WebApplicationFirewallTransform =
        javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.network.enums.WebApplicationFirewallTransform): WebApplicationFirewallTransform =
            WebApplicationFirewallTransform.values().first { it.javaValue == javaType }
    }
}
